chrome.extension.onRequest.addListener(function(request, sender, sendResponse) {
    if (request.method == "getSelection") {
        sendResponse({data: window.getSelection().toString()});
    } else {
        modifyPage(request);
    }
});

chrome.extension.sendRequest({ 'pageLoaded': true }, function (response) {
    modifyPage(response);
});

function modifyPage(request) {

    chrome.extension.sendRequest({'getLocalStorage': true, 'key': 'links'}, function(response) {
        if(response['data']==1) {
            if ( request['parsePage'] ) {
        	    _enabled = true;
        	    parsePage(document.body);
            } else if ( request['clearPage'] ) {
                _enabled = false;
        	    clearPage();
            }
        } 
    });

}

/** Remove click-to-call links and messages **/
function clearPage () {
    $('.fop2-message-box').remove();
    $('.fop2-click-to-call').each(function(){
        $(this).replaceWith(this.innerHTML);
    });
}

/** Parse DOM and convert phone numbers to click-to-call links **/
function parsePage (node) {

    var invalidNodes     = ['SCRIPT', 'STYLE', 'INPUT', 'SELECT', 'TEXTAREA', 'BUTTON', 'A', 'CODE'];
    var nodeName         = node.nodeName.toUpperCase();
    var childNodesLength = node.childNodes.length;

    if ( $.inArray(nodeName, invalidNodes) > -1 || $(node).hasClass('fop2-message-box') ) {
		return 0;
    }

    for (var n = 0; n < childNodesLength; n++) {
		var found = parsePage(node.childNodes[n]);
		if ( found > 0 ) {
	    	parsePage (node);
	    	return 0;
		}
    }

    if (node.nodeType == Node.TEXT_NODE) {
		return findPhones(node);
    } else {
		addEvents(node);
    }
    return 0;
}

/** Replace phone numbers **/
function findPhones (node) {

    if (!node || node.nodeValue.length < 8 || node.nodeValue.search(/\d/) == -1) {
        return 0;
    }

    var phoneNumber = /(\d+?[0-9\(\)\+\-]+)\s?(\d+[0-9\(\)\+\-]+)\s?(\d+[0-9\(\)\+\-]+)\s?(\d+[0-9\(\)\+\-]+)\s?/;
    var phoneNumberEndDelimiter                 = /[\s.,;:|]/;
    var phoneNumberStartDelimiter               = /[\s.,;:|(+]/;
    var somedate1                               = /[0-9]{1,2}[\/-][0-9]{1,2}[\/-][0-9]{4}/;
    var somedate2                               = /[0-9]{4}[\/-][0-9]{1,2}[\/-][0-9]{1,2}\s?/;
    var text        = node.nodeValue;
    var offset      = 0;
    var number      = "";
    var found = false;

    /** Find the first phone number in the text node **/
    while (!found) {

        var result = text.match(phoneNumber);

        if (!result) {
            return 0;
        }
        number = result[0];

        var pos = result.index;
        offset += pos ;

        //console.log("number "+number);
        //console.log("pos "+pos);

        if (pos && !text.substr(pos - 1, 1).match(phoneNumberStartDelimiter)
            || pos + number.length < text.length
            && !text.substr(pos + number.length - 1, 1).match(phoneNumberEndDelimiter)) {

            console.log(number + ' no tiene delimitador feliz');
            console.log(text.substr(pos - 1, 1));
            console.log(text.substr(pos + number.length -1, 1));
            offset += number.length;
            text = text.substr(pos + number.length);
            continue;
        }

        if (text.match(somedate1)) {
            console.log("ignoring some date1 "+text);
            offset += number.length;
            text = text.substr(pos + number.length);
            continue;
        }

        if (text.match(somedate2)) {
            console.log("ignoring some date2 "+text);
            offset += number.length;
            text = text.substr(pos + number.length);
            continue;
        } 

        if (number.length > 20) {
            console.log("muy largo, ignoro");
            offset += number.length;
            text = text.substr(pos + number.length);
            continue;
        }
        console.log(number+' = '+number.length);

        found = true;
    }

    /** handle string address **/
    var stringNumber = number.replace(/sip:/,'');
    var spanNode     = $('<a href="sip:'                     + stringNumber +
			     '" title="Click-to-Call '             + stringNumber +
			     '" class="fop2-click-to-call" rel="' + stringNumber +
			     '"></a>')[0];
//    var spanNode = $('<span title="Click to call ' + stringNumber + '" class="fop2-click-to-call" rel="' + stringNumber + '"></span>')[0];

    var range   = node.ownerDocument.createRange();

    range.setStart(node, offset);
    range.setEnd  (node, offset + number.length );

    var docfrag = range.extractContents();
    var before  = range.startContainer.splitText(range.startOffset);
    var parent  = before.parentNode;

    spanNode.appendChild(docfrag);

    parent.insertBefore(spanNode, before);

    return 1;
}

function addEvents(node) {
    $('.fop2-click-to-call', node).unbind().bind({
        click     : function(e){
            e.preventDefault();
            callNumber (this.innerHTML, this.rel);
            if (e.stopPropagation) e.stopPropagation();
        },
        mouseover : function() {
            var offset, top, left;
            var $this = $(this);
            offset    = $this.offset();
            width     = $this.width();
            top       = offset.top - 5;
            top       = (top > 0) ? top : 0;
            left      = offset.left  + width;
            left      = (left > 0) ? left : 0;

            var icon  = $('<div class="fop2-click-to-call-icon"></div>');
            iconFile  = chrome.extension.getURL('images/telephone19.png');
            icon.css  ({ 'background-image' : 'url(' + iconFile + ')',
                       'top' : top + 'px', 'left' : left + 'px'}).appendTo('body').fadeIn(200);
            $this.data('icon', icon);
        },
         mouseout  : function() {
            var $this  = $(this);
            $this.data('icon').fadeOut(200, function() {
                $(this).remove();
            });
        }
    });
}

$('a[href*="callto"]').each( function() {
            var link = $(this), newUrl = link.attr('href').replace(/^callto:/,'sip:'), phoneNumber = newUrl.replace(/sip:/, '');
            link.attr('href', newUrl);
            link.attr('rel', phoneNumber);
            link.addClass('fop2-click-to-call');
        });

function cleanPhoneNo (str) {
    return str.replace(/[^\d]/g, '');
}

function callNumber(phoneNumber, cleanNumber) {
    var msg = 'Calling number ';
    msg += '[phone :  '   + phoneNumber  + '] - [cleaned:' + cleanNumber + '] ';
    chrome.extension.sendRequest ({ 'makeCall' : true, 'phoneNumber' : cleanNumber }, function (response) {});
}

function debug(text) {
    console.log(text);
}
